@@ -27,10 +27,10 @@ def to_html(filename):
         with open(filename) as f:
             content = f.read()
             # TODO charset detect
-            content = content.decode('utf-8')
-            content = publish_string(writer_name='html',
-                                     source=content)
+            if hasattr(content, 'decode'):
+                content = content.decode('utf-8')
+            content = publish_string(writer_name='html', source=content)
             return content
-    except IOError, e:
+    except IOError as e:
         logging.error(e.strerror)
         raise e
